@@ -71,6 +71,7 @@ class ENHSPEngine(PDDLPlanner):
         supported_kind.set_effects_kind('CONDITIONAL_EFFECTS')  # type: ignore
         supported_kind.set_quality_metrics("ACTIONS_COST")
         supported_kind.set_quality_metrics("PLAN_LENGTH")
+        supported_kind.set_quality_metrics("FINAL_VALUE")
         return supported_kind
 
     @staticmethod
@@ -133,4 +134,6 @@ class ENHSPOptEngine(ENHSPEngine):
         elif plan is None:
             return PlanGenerationResultStatus.UNSOLVABLE_PROVEN
         else:
-            return PlanGenerationResultStatus.SOLVED_OPTIMALLY
+            if not problem.quality_metrics:
+                return PlanGenerationResultStatus.SOLVED_SATISFICING
+            return PlanGenerationResultStatus.SOLVED_OPTIMALLY
\ No newline at end of file
